@@ -25,8 +25,10 @@
 #include "settings.h"
 
 #include <QDateTime>
+#include <QGuiApplication>
 #include <QJsonObject>
 
+#include <KActivities/ResourceInstance>
 #include <KFileMetaData/UserMetaData>
 #include <KLocalizedString>
 
@@ -237,6 +239,9 @@ void DownloadJob::update(const QJsonObject &payload)
             setError(KJob::NoError);
             setProcessedAmount(KJob::Files, 1);
 
+            // Add to recent document
+            addToRecentDocuments();
+
             // Write origin url into extended file attributes
             saveOriginUrl();
 
@@ -254,6 +259,22 @@ void DownloadJob::updateDescription()
     );
 }
 
+void DownloadJob::addToRecentDocuments()
+{
+    if (m_incognito || m_fileName.isEmpty()) {
+        return;
+    }
+
+    const QJsonObject settings = Settings::self().settingsForPlugin(QStringLiteral("downloads"));
+
+    const bool enabled = settings.value(QStringLiteral("addToRecentDocuments")).toBool();
+    if (!enabled) {
+        return;
+    }
+
+    KActivities::ResourceInstance::notifyAccessed(QUrl::fromLocalFile(m_fileName), qApp->desktopFileName());
+}
+
 void DownloadJob::saveOriginUrl()
 {
     if (m_incognito
